@@ -6,9 +6,10 @@ import os
 import os.path
 from subprocess import Popen, PIPE
 from tempfile import NamedTemporaryFile
-from urllib import urlretrieve
 from zipfile import ZipFile
 
+from six.moves.urllib.request import urlretrieve
+
 import nltk
 
 from .._downloader import _make_data_home, _progress
