@@ -64,6 +64,10 @@ def morphy(doc):
     -------
     lemmas : list
         List of lemmas.
+
+    See also
+    --------
+    ``stem_snowball``: simpler approach to lemmatization (stemming).
     """
     # XXX Results will be better if we do POS tagging first, but then we
     # need to map Penn Treebank tags to WordNet tags.
@@ -96,6 +100,23 @@ def _tokenize_if_needed(s):
     return tokenize(s) if isinstance(s, basestring) else s
 
 
+@app.task
+def stem_snowball(doc, language):
+    """Stem words in doc using the Snowball stemmer.
+
+    Set the parameter ``lang`` to a language code such as "de", "en", "nl", or
+    the special string "porter" to get Porter's classic stemming algorithm for
+    English.
+
+    See also
+    --------
+    ``morphy``: smarter approach to stemming (lemmatization), but only for
+    English.
+    """
+    from Stemmer import Stemmer
+    return Stemmer(language).stemWords(_tokenize_if_needed(doc))
+
+
 @app.task
 def stanford_ner_tag(doc, output="tokens"):
     """Named entity recognizer using Stanford NER.
@@ -237,15 +258,16 @@ def untokenize(tokens):
 def frog(doc, output='raw'):
     """Wrapper around the Frog lemmatizer/POS tagger/NER/dependency parser.
 
-    Expects Frog to be running in server mode at localhost:9887. It is *not*
-    started for you.
+    Expects Frog to be running in server mode, listening on
+    ``localhost:${XTAS_FROG_PORT}`` or port 9987 if the environment variable
+    ``XTAS_FROG_PORT`` is not set. It is *not* started for you.
 
     Currently, the module is only tested with all frog modules active except
     for the NER and parser.
 
     The following line starts Frog in the correct way:
 
-    ``frog -S 9887``
+    ``frog -S ${XTAS_FROG_PORT:-9887}``
 
     Parameters
     ----------
@@ -349,7 +371,7 @@ def alpino(doc, output="raw"):
 
     References
     ----------
-    `Alpino homepage <http://www.let.rug.nl/vannoord/alp/Alpino/>`_
+    `Alpino homepage <http://www.let.rug.nl/vannoord/alp/Alpino/>`_.
     """
     from ._alpino import tokenize, parse_raw, interpret_parse
 
@@ -365,15 +387,16 @@ def alpino(doc, output="raw"):
 def corenlp(doc, output='raw'):
     """Wrapper around the CoreNLP parser.
 
-    Expects CORENLP_HOME to point to the CoreNLP installation dir.
+    Expects ``$CORENLP_HOME`` to point to the CoreNLP installation dir.
+
+    Tested with `CoreNLP 2014-01-04
+    <http://nlp.stanford.edu/software/stanford-corenlp-full-2014-01-04.zip>`_.
+
     Parameters
     ----------
     output : string
         If 'raw', returns the raw output lines from CoreNLP.
         If 'saf', returns a SAF dictionary.
-
-    Tested with
-    http://nlp.stanford.edu/software/stanford-corenlp-full-2014-01-04.zip
     """
     from ._corenlp import parse, stanford_to_saf
 
@@ -387,19 +410,18 @@ def corenlp(doc, output='raw'):
 
 @app.task
 def corenlp_lemmatize(doc, output='raw'):
+    """Wrapper around the CoreNLP lemmatizer.
 
-    """
-    Wrapper around the CoreNLP lemmatizer
-    The module expects CORENLP_HOME to point to the CoreNLP installation dir.
+    Expects ``$CORENLP_HOME`` to point to the CoreNLP installation dir.
+
+    Tested with `CoreNLP 2014-01-04
+    <http://nlp.stanford.edu/software/stanford-corenlp-full-2014-01-04.zip>`_.
 
     Parameters
     ----------
     output : string
         If 'raw', returns the raw output lines from CoreNLP.
         If 'saf', returns a SAF dictionary.
-
-    Tested with
-    http://nlp.stanford.edu/software/stanford-corenlp-full-2014-01-04.zip
     """
     from ._corenlp import parse, stanford_to_saf
 
@@ -416,16 +438,16 @@ def semafor(saf):
     """Wrapper around the Semafor semantic parser.
 
     Expects semafor running in server mode listening to
-    SEMAFOR_HOST:SEMAFOR_PORT (defaults to localhost:9888).
-    It also expects CORENLP_HOME to point to the CoreNLP installation dir.
+    ``${SEMAFOR_HOST}:${SEMAFOR_PORT}`` (defaults to localhost:9888).
+    It also expects ``$CORENLP_HOME`` to point to the CoreNLP installation dir.
 
     Input is expected to be a 'SAF' dictionary with trees and tokens.
     Output is a SAF dictionary with a frames attribute added.
 
     References
     ----------
-    `Semafor github page <https://github.com/sammthomson/semafor>'_
-    `CoreNLP home page <http://nlp.stanford.edu/software/corenlp.shtml>'_
+    * `Semafor GitHub page <https://github.com/sammthomson/semafor>'_.
+    * `CoreNLP home page <http://nlp.stanford.edu/software/corenlp.shtml>'_.
     """
     from ._semafor import add_frames
     add_frames(saf)
